import org.jdom.CDATA;
import org.jdom.Element;
import java.util.*;
import java.awt.*;

/**
 * This class represents a layer or a subject category
 *
 * @author Alberto Simes
 */
public class Layer implements XML {

    private Vector elements;
    private String title;
    private String description;

    public Element toXML() {
	Element ge = new Element("layer");
	
	Element e_name = new Element("title");
	e_name.addContent(title);

	Element e_description = new Element("description");
	e_description.addContent(description);

	ge.addContent(e_name);
	ge.addContent(e_description);

	Enumeration elems = elements.elements();
	while (elems.hasMoreElements()) {
	    GeographicElement geographic_elem = (GeographicElement)elems.nextElement();
	    ge.addContent(geographic_elem.toXML());
	}
	return ge;
    }

    /**
     * The constructor initialize a layer with a title (subject name)
     *
     * @param title The title or name of the subject
     */
    public Layer(String title) {
	this.title = new String(title);
	elements = new Vector();
    }

    public Layer(Element el) {
	Iterator it = el.getChildren().iterator();
	elements = new Vector();
	while(it.hasNext()) {
	    Element elem = (Element)it.next();
	    if (elem.getName().equals("title")) {
		this.title = new String(elem.getText());
	    } else 
		if (elem.getName().equals("description")) {
		    this.description = new String(elem.getText());
		}
		else
		    if (elem.getName().equals("element")) {
			elements.add(new GeographicElement(this, elem));
		    }
		    else
		    {
			// RAISE EXCEPTION
		    }
	}
    }

    /**
     * Sets the description for this layer
     *
     * @param description The description for the layer
     * @return            The modified layer
     */
    public Layer setDescription(String description) {
	this.description = new String(description);
	return this;
    }

    /**
     * Adds a geographic element to the layer
     *
     * @param element The name of the element to add
     * @return        The modified layer
     */
    public Layer addElement(String element) {
	elements.addElement(new GeographicElement(this, element));
	return this;
    }

    public void show(Graphics g, boolean z) {
	Enumeration elems = elements.elements();
	while(elems.hasMoreElements()) {
	    GeographicElement ge = (GeographicElement)elems.nextElement();
	    ge.show(g,z);
	}
    }

    /**
     * Returns a string representing the layer (only the title)
     *
     * @return the string representation for the layer
     */
    public String toString() {
	return title;
    }

    public Vector getElements() {
	return this.elements;
    }
}
